Skip to contents

Returns a data frame listing the earliest available year for each state and scraper source tracked by DownBallotR. All sources include data through the current calendar year.

Usage

db_available_years(state = NULL)

Arguments

state

Optional state name to filter results (e.g. "Virginia"). Pass NULL (default) to return all states.

Value

A data.frame with columns source, state, start_year, and end_year.

Examples

# \donttest{
# All sources
db_available_years()
#> Error: Python environment 'downballotR' does not exist.
#> Run downballots_install_python() first.

# Filter to one state
db_available_years(state = "Virginia")
#> Error: Python environment 'downballotR' does not exist.
#> Run downballots_install_python() first.
# }