Skip to contents

List states supported by DownBallotR scrapers

Usage

db_list_states(source = NULL)

Arguments

source

One of the sources returned by db_list_sources(), or NULL (default) to return all states with dedicated scrapers across all sources.

Value

Named character vector of canonical state names. When source = NULL each element is named by its source; when a single source is given the names are omitted.