Returns a data frame listing the earliest available year for each state and scraper source tracked by DownBallotR. All sources include data through the current calendar year.
Examples
# \donttest{
# All sources
db_available_years()
#> Error: Python environment 'downballotR' does not exist.
#> Run downballots_install_python() first.
# Filter to one state
db_available_years(state = "Virginia")
#> Error: Python environment 'downballotR' does not exist.
#> Run downballots_install_python() first.
# }